@@ -1,5 +1,8 @@
+from __future__ import annotations
+
 from abc import ABC
 from dataclasses import dataclass
+from typing import Optional, Tuple
 
 
 class Event(ABC):
@@ -9,6 +12,7 @@ class Event(ABC):
 @dataclass(frozen=True)
 class RawData(Event):
     data: bytes
+    address: Optional[Tuple[str, int]] = None
 
 
 @dataclass(frozen=True)
@@ -18,6 +22,4 @@ class Closed(Event):
 
 @dataclass(frozen=True)
 class Updated(Event):
-    # Indicate that the protocol has updated (although it has nothing
-    # for the server to do).
-    pass
+    idle: bool
